package cd.casic.ci.common.pipeline.pojo.event;

import cd.casic.ci.common.pipeline.enums.CallBackEvent;
import lombok.Data;

import java.util.List;

/**
 * @author by mianbin
 * @Classname CallBackData
 * @Description TODO
 * @Date 2025/4/2 9:46
 */
@Data
class CallBackData<T> {
    private final CallBackEvent event;
    private final T data;

    // 构造函数
    public CallBackData(CallBackEvent event, T data) {
        this.event = event;
        this.data = data;
    }
}

@Data
class PipelineEvent {
    private final String pipelineId;
    private final String pipelineName;
    private final String userId;
    private final long updateTime;
    private final String projectId;
}

@Data
class StreamEnabledEvent {
    private final String userId;
    private final long gitProjectId;
    private final String gitProjectUrl;
    private final boolean enable;
}

@Data
class BuildEvent {
    private final String buildId;
    private final String pipelineId;
    private final String pipelineName;
    private final String userId;
    private final String triggerUser;
    private final String cancelUserId;
    private final String status;
    private final long startTime;
    private final long endTime;
    private final SimpleModel model;
    private final String projectId;
    private final String trigger;
    private final String stageId;
    private final String taskId;
    private final int buildNo;
    private final Boolean debug;

    // 构造函数，使用了默认值的设置
    public BuildEvent(String buildId, String pipelineId, String pipelineName, String userId, String triggerUser, String cancelUserId, String status, long startTime, long endTime, SimpleModel model, String projectId, String trigger, String stageId, String taskId, int buildNo, Boolean debug) {
        this.buildId = buildId;
        this.pipelineId = pipelineId;
        this.pipelineName = pipelineName;
        this.userId = userId;
        this.triggerUser = triggerUser;
        this.cancelUserId = cancelUserId;
        this.status = status;
        this.startTime = startTime;
        this.endTime = endTime;
        this.model = model;
        this.projectId = projectId;
        this.trigger = trigger;
        this.stageId = stageId;
        this.taskId = taskId;
        this.buildNo = buildNo;
        this.debug = debug;
    }
}

@Data
class SimpleModel {
    private final List<SimpleStage> stages;
}

@Data
class SimpleStage {
    private final String stageName;
    private final String name;
    private String status;
    private long startTime;
    private long endTime;
    private final List<SimpleJob> jobs;
}

@Data
class SimpleJob {
    private final String jobName;
    private final String status;
    private final long startTime;
    private final long endTime;
    private final List<SimpleTask> tasks;
}

@Data
class SimpleTask {
    private final String taskId;
    private final String taskName;
    private final String atomCode;
    private final String status;
    private final long startTime;
    private final long endTime;
}

@Data
class ProjectCallbackEvent {
    private final String projectId;
    private final String projectName;
    private final boolean enable;
    private final String userId;
}

// 定义回调常量的类
class CallbackConstants {
    // 项目级回调标志位
    static final String DEVOPS_ALL_PROJECT = "DEVOPS_ALL_PROJECT";
}
