package cd.casic.ci.common.pipeline.utils;

import cd.casic.ci.common.pipeline.enums.BuildFormPropertyType;
import cd.casic.ci.common.pipeline.pojo.cascade.RepoRefCascadeParam;
import cd.casic.framework.commons.util.json.JsonUtils;
import cn.hutool.json.JSONUtil;
import com.fasterxml.jackson.core.type.TypeReference;
import lombok.extern.slf4j.Slf4j;

import java.util.Map;

/**
 * @Author：mianbin
 * @Package：cd.casic.ci.common.pipeline.utils
 * @Project：ops-pro
 * @name：CascadePropertyUtils
 * @Date：2025/03/26 15:02
 * @Filename：CascadePropertyUtils
 * @description：Todo
 */
@Slf4j
public class CascadePropertyUtils {
    public static Map<String, String> getCascadeVariableKeyMap(String key, BuildFormPropertyType type) {
        return type == BuildFormPropertyType.REPO_REF ? RepoRefCascadeParam.variableKeyMap(key) : Map.of();
    }

    public static Map<String, String> parseDefaultValue(String key, Object defaultValue, BuildFormPropertyType type) {
        try {
            if (defaultValue instanceof String) {
                return JsonUtils.parseObject((String) defaultValue, new TypeReference<Map<String, String>>() {
                });
            } else {
                return (Map<String, String>) defaultValue;
            }
        } catch (Exception ignored) {
            log.warn("parse repo ref error, key: {}, defaultValue: {}", key, defaultValue);
            return getDefaultValue(type);
        }
    }

    private static Map<String, String> getDefaultValue(BuildFormPropertyType type) {
        return type == BuildFormPropertyType.REPO_REF ? RepoRefCascadeParam.defaultValue() : Map.of();
    }

    public static boolean supportCascadeParam(BuildFormPropertyType type) {
        return type == BuildFormPropertyType.REPO_REF;
    }
}
