package cd.casic.ci.log.jmx;

import lombok.Synchronized;
import org.springframework.jmx.export.annotation.ManagedResource;
import org.springframework.stereotype.Component;

import java.util.concurrent.atomic.AtomicLong;

/**
 * @author by mianbin
 * @Classname LogStorageBean
 * @Description * 日志保存模块，主要是使用原子类和 synchronized 关键字来保证并发性,记录每个操作的次数。
 * @Date 2025/3/20 10:26
 */
@Component
@ManagedResource(objectName = "ops.ci.log.v2:type=logs", description = "log performance")
public class LogStorageBean {

    private AtomicLong batchWriteCount = new AtomicLong(0);
    private AtomicLong batchWriteElapse = new AtomicLong(0);
    private AtomicLong calculateCount = new AtomicLong(0);
    private AtomicLong failureCount = new AtomicLong(0);
    private AtomicLong bulkRequestCount = new AtomicLong(0);
    private AtomicLong bulkRequestElapse = new AtomicLong(0);
    private AtomicLong bulkRequestFailureCount = new AtomicLong(0);
    private AtomicLong queryLogCount = new AtomicLong(0);
    private AtomicLong queryLogElapse = new AtomicLong(0);
    private AtomicLong queryCalculateCount = new AtomicLong(0);
    private AtomicLong queryFailureCount = new AtomicLong(0);
    private AtomicLong downloadLogCount = new AtomicLong(0);
    private AtomicLong downloadLogElapse = new AtomicLong(0);
    private AtomicLong downloadCalculateCount = new AtomicLong(0);
    private AtomicLong downloadFailureCount = new AtomicLong(0);

    @Synchronized
    public void query(Long elapse, boolean success) {
        queryLogCount.incrementAndGet();
        queryCalculateCount.incrementAndGet();
        queryLogElapse.addAndGet(elapse);
        if (!success) {
            queryFailureCount.incrementAndGet();
        }
    }

    @Synchronized
    public void batchWrite(long elapse, boolean success) {
        batchWriteCount.incrementAndGet();
        calculateCount.incrementAndGet();
        batchWriteElapse.addAndGet(elapse);
        if (!success) {
            failureCount.incrementAndGet();
        }
    }

}
