package cd.casic.pipeline.store.api.common;

import cd.casic.framework.commons.pojo.CommonResult;
import cd.casic.framework.commons.pojo.PageResult;
import cd.casic.pipeline.store.pojo.common.enums.StoreTypeEnum;
import cd.casic.pipeline.store.pojo.common.sensitive.SensitiveApiApproveReq;
import cd.casic.pipeline.store.pojo.common.sensitive.SensitiveApiInfo;
import io.swagger.v3.oas.annotations.Operation;
import io.swagger.v3.oas.annotations.Parameter;
import io.swagger.v3.oas.annotations.tags.Tag;
import org.springframework.web.bind.annotation.*;

import static cd.casic.ci.common.pipeline.constant.OpsHeader.AUTH_HEADER_USER_ID;

@Tag(name = "OP_SDK_SENSITIVEAPI", description = "OP-敏感API")
@RestController
@RequestMapping("/op/sdk/sensitiveApi/")
public interface OpSensitiveApiResource {

    @Operation(summary = "查看敏感API列表")
    @GetMapping("list")
    PageResult<SensitiveApiInfo> list(
            @Parameter(description = "store组件类别 ATOM:插件 TEMPLATE:模板 IMAGE:镜像 IDE_ATOM:IDE插件")
            @RequestParam("storeType")
            StoreTypeEnum storeType,
            @Parameter(description = "store组件代码")
            @RequestParam("storeCode")
            String storeCode,
            @Parameter(description = "API名称")
            @RequestParam("apiName")
            String apiName,
            @Parameter(description = "API等级 NORMAL: 普通 SENSITIVE: 敏感")
            @RequestParam("apiLevel")
            String apiLevel,
            @Parameter(description = "API状态 WAIT:待审批，PASS:通过，REFUSE:拒绝, CANCEL: 取消")
            @RequestParam("apiStatus")
            String apiStatus,
            @Parameter(description = "第几页", required = false)
            @RequestParam("page")
            Integer page,
            @Parameter(description = "每页条数", required = false)
            @RequestParam("pageSize")
            Integer pageSize
    );

    @Operation(summary = "敏感API审批")
    @PutMapping("approve")
    CommonResult<Boolean> approve(
            @Parameter(description = "userId", required = true)
            @RequestHeader(AUTH_HEADER_USER_ID)
            String userId,
            @Parameter(description = "敏感API审批请求体")
            SensitiveApiApproveReq sensitiveApiApproveReq
    );
}