package cd.casic.pipeline.store.constant;

import lombok.Getter;

/**
 * 流水线微服务模块请求返回状态码
 * 返回码制定规则（0代表成功，为了兼容历史接口的成功状态都是返回0）：
 * 1、返回码总长度为7位，
 * 2、前2位数字代表系统名称（如21代表持续集成平台）
 * 3、第3位和第4位数字代表微服务模块（00：common-公共模块 01：process-流水线 02：artifactory-版本仓库 03:dispatch-分发 04：dockerhost-docker机器
 *    05:environment-环境 06：experience-版本体验 07：image-镜像 08：log-日志 09：measure-度量 10：monitoring-监控 11：notify-通知
 *    12：openapi-开放api接口 13：plugin-插件 14：quality-质量红线 15：repository-代码库 16：scm-软件配置管理 17：support-支撑服务
 *    18：ticket-证书凭据 19：project-项目管理 20：store-商店 21： auth-权限 22:sign-签名服务 23:metrics-度量服务 24：external-外部
 *    25：prebuild-预建 26: dispatcher-kubernetes 27：buildless 28: lambda 29: stream  30: worker 31: dispatcher-docker
 *    32: remotedev 35：misc-杂项）
 * 4、最后3位数字代表具体微服务模块下返回给客户端的业务逻辑含义（如001代表系统服务繁忙，建议一个模块一类的返回码按照一定的规则制定）
 * 5、系统公共的返回码写在CommonMessageCode这个类里面，具体微服务模块的返回码写在相应模块的常量类里面
 *
 * @since: 2023-3-20
 * @version: $Revision$ $Date$ $LastChangedBy$
 *
 */
@Getter
public final class StoreMessageCode {
    
    public static final String MSG_CODE_BUILD_TYPE_PREFIX = "buildType."; // 构建资源类型国际化前缀

    public static final String USER_QUERY_ATOM_PERMISSION_IS_INVALID = "2120001"; // 研发商店：没有插件的查看权限
    public static final String USER_QUERY_PROJECT_PERMISSION_IS_INVALID = "2120002"; // 研发商店：没有项目的查看权限
    public static final String USER_CREATE_REPOSITORY_FAIL = "2120003"; // 研发商店：创建代码库失败，请稍后再试
    public static final String USER_INSTALL_ATOM_CODE_IS_INVALID = "2120004"; // 研发商店：安装插件失败
    public static final String USER_REPOSITORY_PULL_TASK_JSON_FILE_FAIL = "2120005"; // 研发商店：从[{0}]分支拉取插件配置文件[task.json]失败,请确认是否OAUTH授权、文件是否正确上传代码库等
    public static final String USER_REPOSITORY_TASK_JSON_FIELD_IS_NULL = "2120006"; // 研发商店：插件配置文件[task.json]{0}字段不能为空
    public static final String USER_REPOSITORY_TASK_JSON_FIELD_IS_NOT_MATCH = "2120007"; // 研发商店：插件配置文件[task.json]{0}字段与工作台录入的不一致
    public static final String USER_ATOM_RELEASE_STEPS_ERROR = "2120008"; // 研发商店：插件发布流程状态变更顺序不正确
    public static final String USER_ATOM_VERSION_IS_NOT_FINISH = "2120009"; // 研发商店：插件{0}的{1}版本发布未结束，请稍后再试
    public static final String USER_ATOM_VERSION_IS_INVALID = "2120010"; // 研发商店：插件升级的版本号{0}错误，应为{1}
    public static final String USER_LOGO_SIZE_IS_INVALID = "2120011"; // logo的尺寸应为{0}x{1}
    public static final String USER_LOGO_TYPE_IS_NOT_SUPPORT = "2120012"; // logo不支持{0}类型，可以上传{1}类型
    public static final String UPLOAD_LOGO_IS_TOO_LARGE = "2120013"; // 研发商店：上传的logo文件不能超过{0}
    public static final String USER_ATOM_CONF_INVALID = "2120014"; // 研发商店：插件配置文件{0}格式不正确，错误原因:{1}
    public static final String USER_ATOM_VISIBLE_DEPT_IS_INVALID = "2120015"; // 研发商店：你不在{0}插件的可见范围之内，请联系插件发布者
    public static final String USER_COMPONENT_ADMIN_COUNT_ERROR = "2120016"; // 研发商店：管理员个数不能少于1个
    public static final String ADD_ATOM_PLATFORM_INFO_FAILED = "2120017"; // 添加插件对接平台信息失败
    public static final String USER_ATOM_QUALITY_CONF_INVALID = "2120018"; // 研发商店：插件配置文件[quality.json]{0}格式不正确，请检查
    public static final String USER_REPOSITORY_PULL_QUALITY_JSON_FILE_FAIL = "2120019"; // 研发商店：从[{0}]分支拉取插件配置文件[quality.json]失败,请确认是否OAUTH授权、文件是否正确上传代码库等
    public static final String USER_ATOM_USED = "2120020"; // 研发商店：插件{0}已被项目{1}下的流水线使用，不可以卸载
    public static final String USER_ATOM_UNINSTALL_REASON_USED = "2120021"; // 研发商店：插件卸载原因{0}已被使用，不能删除。建议禁用
    public static final String USER_COMPONENT_RELEASED_IS_NOT_ALLOW_DELETE = "2120022"; // 研发商店：组件{0}已发布到商店，请先下架再删除
    public static final String USER_ATOM_USED_IS_NOT_ALLOW_DELETE = "2120023"; // 研发商店：插件{0}已安装到其他项目下使用，请勿移除
    public static final String USER_REPOSITORY_BK_FRONTEND_DIR_IS_NULL = "2120024"; // 研发商店：插件代码库文件夹[{0}]未创建
    public static final String USER_ATOM_IS_NOT_ALLOW_USE_IN_PROJECT = "2120025"; // 你的项目[{0}]不允许使用插件[{1}]，请检查插件是否被正确安装
    public static final String USER_REPOSITORY_TASK_JSON_FIELD_IS_INVALID = "2120026"; // 研发商店：插件配置文件[task.json]{0}格式不正确，请检查
    public static final String USER_ATOM_IS_NOT_ALLOW_REPLACE = "2120027"; // 研发商店：插件[{0}]的[{1}]版本无法被插件[{2}]的[{3}]版本替换，插件[{2}]的{4}参数无法映射替换
    public static final String USER_TO_ATOM_IS_NOT_BE_HIS_ATOM = "2120028"; // 研发商店：目标替换插件不能是历史内置老插件
    public static final String USER_ATOM_NOT_COMPATIBLE_INPUT_FIELD = "2120029"; // 研发商店：插件当前版本新增了无默认值的必填入参[{0}]，将导致存量流水线执行异常，请修改发布类型进行非兼容式升级
    public static final String USER_ATOM_COMPATIBLE_INPUT_FIELD_CONFIRM = "2120030"; // 研发商店：插件当前版本新增了入参[{0}]，请确认插件执行逻辑对这些参数不存在或值为空的情况做了兼容处理，否则有可能导致存量流水线执行异常
    public static final String USER_ATOM_COMPATIBLE_OUTPUT_FIELD_CONFIRM = "2120031"; // 研发商店：插件当前版本减少了出参[{0}]，请确认插件执行逻辑对这些参数不存在或值为空的情况做了兼容处理，否则有可能导致存量流水线执行异常
    public static final String USER_ATOM_INPUT_NUM_IS_TOO_MANY = "2120032"; // 研发商店：插件入参数量太多，系统规定的数量最大为：{0}
    public static final String USER_ATOM_OUTPUT_NUM_IS_TOO_MANY = "2120033"; // 研发商店：插件出参数量太多，系统规定的数量最大为：{0}
    public static final String USER_REPOSITORY_TASK_JSON_OS_DEFAULT_ENV_IS_INVALID = "2120034"; // 研发商店：配置文件[{0}]{1}操作系统默认环境配置数量为{2}个，默认环境配置数量有且只能为1个
    public static final String USER_REPOSITORY_PULL_ERROR_JSON_FILE_FAIL = "2120035"; // 研发商店：从[{0}]分支拉取插件配置文件[error.json]失败,请确认是否OAUTH授权、文件是否正确上传代码库等
    public static final String USER_REPOSITORY_ERROR_JSON_ERROR_CODE_EXIST_DUPLICATE = "2120036"; // 研发商店：插件配置文件[error.json]errorCode字段数据重复，请检查{0}
    public static final String USER_REPOSITORY_ERROR_JSON_FIELD_IS_INVALID = "2120037"; // 研发商店：插件配置文件[error.json]errorCode格式不正确，请检查
    public static final String TASK_JSON_CONFIGURE_FORMAT_ERROR = "2120038"; // 参数[{0}] 的{1} ,请检查task.json配置格式是否正确 \n
    public static final String GET_ATOM_LANGUAGE_ENV_INFO_FAILED = "2120039"; // 获取插件开发语言相关的环境变量信息失败
    public static final String TASK_JSON_CONFIG_IS_INVALID = "2120040"; // 研发商店：插件配置文件[task.json]config配置格式不正确,{0}
    public static final String USER_PULL_FILE_FAIL = "2120041"; // 研发商店: 拉取文件[{0}]失败，失败原因：{1}
    public static final String ATOM_PACKAGE_FILE_NOT_FOUND = "2120042"; // 插件包文件[{0}]不存在，请检查文件所在路径是否正确

    private StoreMessageCode() {
        throw new IllegalStateException("Utility class");
    }
}